BooleanPicker class

Provides interactive terminal menu for selecting a boolean value. This picker is specialized for boolean type parameters with exactly 2 options.

Constructors

BooleanPicker()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

pick(String parameterName, {String? description}) String?
Shows an interactive menu to select a boolean value. Returns the selected value ('true' or 'false') or null if cancelled.