SwitchPicker class

Provides interactive terminal menu for selecting a switch case.

Constructors

SwitchPicker()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

pick(Command command, String commandPath) → String?
Shows an interactive menu to select a switch case from the given command. Returns the selected switch name or null if cancelled.